
.. blogpost::
    :title: Nice extensions to scikit-learn
    :keywords: mlxtend, gnumpy, scacredn nolearn, pystruct
    :date: 2016-03-19
    :categories: module

    Some projects mentioned at
    `Related Projects (to scikit-learn) <http://scikit-learn.org/stable/related_projects.html>`_:

    * `sklearn_pandas <https://github.com/paulgb/sklearn-pandas>`_:
      this module provides a bridge between Scikit-Learn's machine learning methods and pandas-style Data Frames.
    * `gplearn <https://github.com/trevorstephens/gplearn>`_:
      gplearn implements Genetic Programming in Python, with a scikit-learn inspired and compatible API."),
    * `nolearn <https://pythonhosted.org/nolearn/>`_:
      contains a number of wrappers and abstractions around existing neural network libraries, most notably Lasagne, along with a few machine learning utility modules. All code is written to be compatible with scikit-learn.
    * `mlxtend <https://github.com/rasbt/mlxtend>`_: check out the
      `documentation <http://rasbt.github.io/mlxtend/>`_, really nice,
      this is a  library consisting of useful tools and extensions for the day-to-day data science tasks.
    * `sacred <https://github.com/IDSIA/sacred>`_:
      facilitates automated and reproducible experimental research.

    And some others with C++ inside:

    * `pystruct <https://pystruct.github.io/>`_:
      learning Structured Prediction in Python.
    * `seqlearn <https://github.com/larsmans/seqlearn>`_:
      sequence classification toolkit for Python. It is designed to extend scikit-learn and offer as similar as possible an API.
    * `py-earth <https://github.com/jcrudy/py-earth>`_:
      a Python implementation of Jerome Friedman's Multivariate Adaptive Regression Splines algorithm, in the style of scikit-learn.
    * `hmmlearn <https://github.com/hmmlearn/hmmlearn>`_:
      Hidden Markov Models in Python, with scikit-learn like API.
